import rclpy
from rclpy.node import Node,Parameter
from rcl_interfaces.srv import SetParametersAtomically

class CameraClient(Node):
    def __init__(self):
        super().__init__('camera_client')
        self.cli_info = self.create_client(SetParametersAtomically, '/camera_node/set_parameters_atomically')
        while not self.cli_info.wait_for_service(timeout_sec=1.0):
            self.get_logger().info('service not available, waiting again...')
        
    def update(self, info):
        self.req_info = SetParametersAtomically.Request()
        self.req_info.parameters= [i.to_parameter_msg() for i in info]
        self.future_info = self.cli_info.call_async(self.req_info)
        rclpy.spin_until_future_complete(self, self.future_info)
        return self.future_info.result()
            
def main(args=None):
    rclpy.init(args=args)
    camera_client = CameraClient()

    params_list = [
        Parameter(name='enable', value = True),
        Parameter(name='type',  value = 'video'),
        Parameter(name='src',  value = '/home/user/Desktop/henry/zhuhai_street_20231029/zhuhai_street_20231029.mp4'),
        Parameter(name='height',  value = 320),
        Parameter(name='width',  value = 320),
    ]
    response = camera_client.update(params_list)
    print(response)
    
    camera_client.destroy_node()
    rclpy.shutdown()
    
if __name__ == '__main__':
    main()
    
    # camera_toggle.update_info(camera_config=CameraInfo(height=320,width=320))